@@ -4,13 +4,13 @@ import traceback
 from scalene import scalene_profiler
 
 
-def should_trace(s) -> bool:
+def should_trace(s: str) -> bool:
     if scalene_profiler.Scalene.is_done():
         return False
     return scalene_profiler.Scalene.should_trace(s)
 
 
-def main():
+def main() -> None:
     try:
         from scalene import scalene_profiler
 
