@@ -1,18 +1,25 @@
 import webbrowser
 from typing import Optional
 
-def find_browser(browserClass=None) -> Optional[str]:
+
+def find_browser(browserClass: Optional[str] = None) -> Optional[str]:
     """Find the default system browser, excluding text browsers.
-    
+
     If you want a specific browser, pass its class as an argument."""
     text_browsers = [
-        "browsh", "elinks", "links", "lynx", "w3m",
+        "browsh",
+        "elinks",
+        "links",
+        "lynx",
+        "w3m",
     ]
 
     try:
         # Get the default browser object
         browser = webbrowser.get(browserClass)
-        browser_name = browser.name if browser.name else browser.__class__.__name__
+        browser_name = (
+            browser.name if browser.name else browser.__class__.__name__
+        )
         return browser_name if browser_name not in text_browsers else None
     except AttributeError:
         # https://github.com/plasma-umass/scalene/issues/790
@@ -21,7 +28,7 @@ def find_browser(browserClass=None) -> Optional[str]:
         # we need to refer to it as such to prevent this error:
         #   'MacOSXOSAScript' object has no attribute 'name'
         browser = webbrowser.get(browserClass)
-        return browser._name if browser._name not in text_browsers else None
+        return browser._name if browser._name not in text_browsers else None  # type: ignore[attr-defined]
     except webbrowser.Error:
         # Return None if there is an error in getting the browser
         return None
