@@ -2,6 +2,7 @@ import argparse
 import os
 import sys
 from textwrap import dedent
+
 from scalene.scalene_signals import ScaleneSignals
 
 usage = dedent("""Turn Scalene profiling on or off for a specific process.""")
@@ -26,10 +27,10 @@ if len(sys.argv) == 1 or args.pid == 0:
 
 try:
     if args.on:
-        os.kill(args.pid, ScaleneSignals.start_profiling_signal)
+        os.kill(args.pid, ScaleneSignals().start_profiling_signal)
         print("Scalene: profiling turned on.")
     else:
-        os.kill(args.pid, ScaleneSignals.stop_profiling_signal)
+        os.kill(args.pid, ScaleneSignals().stop_profiling_signal)
         print("Scalene: profiling turned off.")
 
 except ProcessLookupError:
