@@ -35,4 +35,7 @@ def replacement_poll_selector(scalene: Scalene) -> None:
                     if end_time - start_time >= timeout:
                         return []  # None
 
+    ReplacementPollSelector.__qualname__ = (
+        "replacement_poll_selector.ReplacementPollSelector"
+    )
     selectors.PollSelector = ReplacementPollSelector  # type: ignore
