@@ -106,7 +106,6 @@ from scalene.scalene_accelerator import ScaleneAccelerator
 
 console = Console(style="white on blue")
 
-
 # Assigning to `nada` disables any console.log commands.
 def nada(*args: Any) -> None:
     pass
@@ -376,48 +375,6 @@ class Scalene:
             )
             Scalene.update_line()
 
-    @staticmethod
-    def invalidate_lines_python(
-        frame: FrameType, _event: str, _arg: str
-    ) -> Any:
-        """Mark the last_profiled information as invalid as soon as we execute a different line of code."""
-        try:
-            # If we are still on the same line, return.
-            ff = frame.f_code.co_filename
-            fl = frame.f_lineno
-            (fname, lineno, lasti) = Scalene.last_profiled_tuple()
-            if (ff == fname) and (fl == lineno):
-                return Scalene.invalidate_lines_python
-            # Different line: stop tracing this frame.
-            frame.f_trace = None
-            frame.f_trace_lines = False
-            if on_stack(frame, fname, lineno):
-                # We are still on the same line, but somewhere up the stack
-                # (since we returned when it was the same line in this
-                # frame). Stop tracing in this frame.
-                return None
-            # We are on a different line; stop tracing and increment the count.
-            sys.settrace(None)
-            Scalene.update_profiled()
-            Scalene.__last_profiled_invalidated = True
-
-            Scalene.__last_profiled = [
-                Filename("NADA"),
-                LineNumber(0),
-                ByteCodeIndex(0),
-                #     Filename(ff),
-                #     LineNumber(fl),
-                #     ByteCodeIndex(frame.f_lasti),
-            ]
-            return None
-        except AttributeError:
-            # This can happen when Scalene shuts down.
-            return None
-        except Exception as e:
-            print(f"{Scalene.__error_message}:\n", e, file=sys.stderr)
-            traceback.print_exc()
-            return None
-
     @classmethod
     def clear_metrics(cls) -> None:
         """Clear the various states for forked processes."""
@@ -575,13 +532,21 @@ class Scalene:
         ):
             Scalene.update_profiled()
         pywhere.set_last_profiled_invalidated_false()
-        Scalene.__last_profiled = [
+        # In the setprofile callback, we rely on 
+        # __last_profiled always having the same memory address. 
+        # This is an optimization to not have to traverse the Scalene profiler
+        # object's dictionary every time we want to update the last profiled line.
+        #
+        # A previous change to this code set Scalene.__last_profiled = [fname, lineno, lasti],
+        # which created a new list object and set the __last_profiled attribute to the new list. This 
+        # made the object held in `pywhere.cpp` out of date, and caused the profiler to not update the last profiled line.
+        Scalene.__last_profiled[:] = [
             Filename(f.f_code.co_filename),
             LineNumber(f.f_lineno),
             ByteCodeIndex(f.f_lasti),
         ]
         Scalene.__alloc_sigq.put([0])
-        pywhere.enable_settrace()
+        pywhere.enable_settrace(this_frame)
         del this_frame
 
     @staticmethod
@@ -752,15 +717,14 @@ class Scalene:
             cmdline += f" --pid={os.getpid()} ---"
             # Build the commands to pass along other arguments
 
-            # Since we're joining by spaces, we need to escape the spaces in the LD_LIBRARY_PATH.
-            environ = ScalenePreload.get_preload_environ(Scalene.__args, escape_spaces=True)
+            environ = ScalenePreload.get_preload_environ(Scalene.__args)
             if sys.platform == "win32":
                 preface = "\n".join(
                     f"set {k}={str(v)}\n" for (k, v) in environ.items()
                 )
             else:
                 preface = " ".join(
-                    "=".join((k, str(v))) for (k, v) in environ.items()
+                    "=".join((k, f"'{str(v)}'")) for (k, v) in environ.items()
                 )
 
             Scalene.__orig_python = redirect_python(
@@ -891,7 +855,11 @@ class Scalene:
                 return True
             outfile = Scalene.__output.output_file
             if Scalene.__args.outfile:
-                outfile = Scalene.__args.outfile
+                outfile = os.path.join(
+                    os.path.dirname(Scalene.__args.outfile),
+                    os.path.splitext(os.path.basename(Scalene.__args.outfile))[0] + ".json"
+                )
+                # outfile = Scalene.__args.outfile
             # If there was no output file specified, print to the console.
             if not outfile:
                 if sys.platform == "win32":
@@ -1320,6 +1288,9 @@ class Scalene:
                 bytei,
             ) = item
             is_malloc = action == Scalene.MALLOC_ACTION
+            if count == scalene.scalene_config.NEWLINE_TRIGGER_LENGTH + 1: 
+                continue # in previous implementations, we were adding NEWLINE to the footprint.
+                         # We should not account for this in the user-facing profile. 
             count /= Scalene.BYTES_PER_MB
             if is_malloc:
                 stats.current_footprint += count
@@ -1750,6 +1721,7 @@ class Scalene:
             Scalene.timer_signals = False
             return
         try:
+            assert Scalene.__signals.cpu_timer_signal is not None
             Scalene.__orig_setitimer(Scalene.__signals.cpu_timer_signal, 0)
             for sig in [
                 Scalene.__signals.malloc_signal,
@@ -1860,6 +1832,7 @@ class Scalene:
                         "Scalene can only profile code that runs for at least one second or allocates at least 10MB.",
                         file=sys.stderr,
                     )
+
             if not (
                 did_output
                 and Scalene.__args.web
@@ -1868,12 +1841,18 @@ class Scalene:
             ):
                 return exit_status
 
-            if Scalene.__args.web:
-                # Only generate HTML file if needed for display in the browser.
+            if Scalene.__args.web or Scalene.__args.html:
+                profile_filename = Scalene.__profile_filename
+                if Scalene.__args.outfile:
+                    profile_filename = os.path.join(
+                        os.path.dirname(Scalene.__args.outfile),
+                        os.path.splitext(os.path.basename(Scalene.__args.outfile))[0] + ".json"
+                    )
                 generate_html(
-                    profile_fname=Scalene.__profile_filename,
+                    profile_fname=profile_filename,
                     output_fname=(
-                        Scalene.__profiler_html
+                        Scalene.__profiler_html if not Scalene.__args.outfile
+                        else Scalene.__args.outfile
                     ),
                 )
             if Scalene.in_jupyter():
@@ -1960,7 +1939,7 @@ class Scalene:
 
                 Scalene.__accelerator = ScaleneAppleGPU()
             else:
-                from scalene.scalene_nvidia_gpu import ScaleneNVIDIAGPU  # type: ignore
+                from scalene.scalene_nvidia_gpu import ScaleneNVIDIAGPU
 
                 Scalene.__accelerator = ScaleneNVIDIAGPU()
 
