@@ -5,9 +5,9 @@ import pathlib
 import pickle
 import time
 from collections import defaultdict
+from pydantic import PositiveInt
 from typing import (
     Any,
-    DefaultDict,
     Dict,
     List,
     NewType,
@@ -23,7 +23,7 @@ from scalene.runningstats import RunningStats
 
 Address = NewType("Address", str)
 Filename = NewType("Filename", str)
-LineNumber = NewType("LineNumber", int)
+LineNumber = NewType("LineNumber", PositiveInt)
 ByteCodeIndex = NewType("ByteCodeIndex", int)
 T = TypeVar("T")
 
@@ -67,8 +67,8 @@ class ScaleneStatistics:
         )
 
         #   GPU memory samples for each location in the program
-        self.gpu_mem_samples: DefaultDict[
-            Filename, DefaultDict[LineNumber, RunningStats]
+        self.gpu_mem_samples: Dict[
+            Filename, Dict[LineNumber, RunningStats]
         ] = defaultdict(lambda: defaultdict(RunningStats))
 
         # Running stats for the fraction of time running on the CPU.
