@@ -70,7 +70,7 @@ def get_fully_qualified_name(frame: FrameType) -> Filename:
     version = sys.version_info
     if version.major >= 3 and version.minor >= 11:
         # Introduced in Python 3.11
-        fn_name = Filename(frame.f_code.co_qualname)  # type: ignore
+        fn_name = Filename(frame.f_code.co_qualname)
         return fn_name
     f = frame
     # Manually search for an enclosing class.
@@ -110,12 +110,26 @@ def generate_html(profile_fname: Filename, output_fname: Filename) -> None:
         directory: str, subdirectory: str, filename: str
     ) -> str:
         file_path = os.path.join(directory, subdirectory, filename)
-        return pathlib.Path(file_path).read_text()
+        file_content = ""
+        try:
+            file_content = pathlib.Path(file_path).read_text(encoding="utf-8")
+        except UnicodeDecodeError as e:
+            raise UnicodeDecodeError(
+                f"Failed to decode file {file_path}. Ensure the file is UTF-8 encoded."
+            ) from e
+        return file_content
 
     try:
         # Load the profile
         profile_file = pathlib.Path(profile_fname)
-        profile = profile_file.read_text()
+        profile = ""
+        try:
+            profile = profile_file.read_text(encoding="utf-8")
+        except UnicodeDecodeError as e:
+            raise UnicodeDecodeError(
+                f"Failed to decode file {profile_file}. Ensure the file is UTF-8 encoded."
+            ) from e
+            
     except FileNotFoundError:
         assert profile_fname == "demo"
         profile = ""
@@ -126,20 +140,11 @@ def generate_html(profile_fname: Filename, output_fname: Filename) -> None:
 
     file_contents = {
         "scalene_gui_js_text": read_file_content(
-            scalene_dir, "scalene-gui", "scalene-gui.js"
+            scalene_dir, "scalene-gui", "scalene-gui-bundle.js"
         ),
         "prism_css_text": read_file_content(
             scalene_dir, "scalene-gui", "prism.css"
         ),
-        "prism_js_text": read_file_content(
-            scalene_dir, "scalene-gui", "prism.js"
-        ),
-        "tablesort_js_text": read_file_content(
-            scalene_dir, "scalene-gui", "tablesort.js"
-        ),
-        "tablesort_number_js_text": read_file_content(
-            scalene_dir, "scalene-gui", "tablesort.number.js"
-        ),
     }
 
     # Put the profile and everything else into the template.
@@ -151,9 +156,6 @@ def generate_html(profile_fname: Filename, output_fname: Filename) -> None:
         profile=profile,
         gui_js=file_contents["scalene_gui_js_text"],
         prism_css=file_contents["prism_css_text"],
-        prism_js=file_contents["prism_js_text"],
-        tablesort_js=file_contents["tablesort_js_text"],
-        tablesort_number_js=file_contents["tablesort_number_js_text"],
         scalene_version=scalene_version,
         scalene_date=scalene_date,
     )
